==> apache-streampipes-0.91.0-source-release.zip: apache-streampipes-0.91.0/streampipes-pipeline-management/src/test/java/org/apache/streampipes/manager/matching/v2/TestMeasurementUnitMatch.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package org.apache.streampipes.manager.matching.v2;

import org.apache.streampipes.model.client.matching.MatchingResultMessage;

import org.junit.Test;

import java.net.URI;
import java.util.ArrayList;
import java.util.List;

import static org.junit.Assert.assertTrue;

public class TestMeasurementUnitMatch {

  @Test
  public void testPositiveMeasurementUnitMatch() {
    URI offered = URI.create("http://qudt.org/1.1/schema/qudt#DegreeCelsius");
    URI required = URI.create("http://qudt.org/1.1/schema/qudt#DegreeCelsius");

    List<MatchingResultMessage> errorLog = new ArrayList<>();

    boolean matches = new MeasurementUnitMatch().match(offered, required, errorLog);
    assertTrue(matches);
  }
}

==> apache-streampipes-0.97.0-source-release.zip: apache-streampipes-0.97.0/streampipes-pipeline-management/src/test/java/org/apache/streampipes/manager/matching/v2/TestMeasurementUnitMatch.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package org.apache.streampipes.manager.matching.v2;

import org.apache.streampipes.model.client.matching.MatchingResultMessage;

import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;

import java.net.URI;
import java.util.ArrayList;
import java.util.List;

public class TestMeasurementUnitMatch {

  @Test
  public void testPositiveMeasurementUnitMatch() {
    URI offered = URI.create("http://qudt.org/1.1/schema/qudt#DegreeCelsius");
    URI required = URI.create("http://qudt.org/1.1/schema/qudt#DegreeCelsius");

    List<MatchingResultMessage> errorLog = new ArrayList<>();

    boolean matches = new MeasurementUnitMatch().match(offered, required, errorLog);
    Assertions.assertTrue(matches);
  }
}
